@@ -9,7 +9,6 @@
 
 // Qt
 #include <QFile>
-#include <QMap>
 #include <QStandardPaths>
 
 // KF
@@ -24,25 +23,8 @@ namespace {
 constexpr int kLayoutVersionFormat = 1;
 }
 
-class KMahjonggLayoutPrivate
-{
-public:
-    KMahjonggLayoutPrivate()
-    {
-        board = new BoardLayout();
-    }
-    ~KMahjonggLayoutPrivate()
-    {
-        delete board;
-    }
-
-    BoardLayout * board;
-    QMap<QString, QString> authorproperties;
-    QString filename;
-};
-
 KMahjonggLayout::KMahjonggLayout()
-    : d(new KMahjonggLayoutPrivate)
+    : m_board(new BoardLayout())
 {
     static bool s_inited = false;
     if (s_inited) {
@@ -52,10 +34,7 @@ KMahjonggLayout::KMahjonggLayout()
     s_inited = true;
 }
 
-KMahjonggLayout::~KMahjonggLayout()
-{
-    delete d;
-}
+KMahjonggLayout::~KMahjonggLayout() = default;
 
 bool KMahjonggLayout::loadDefault()
 {
@@ -75,17 +54,21 @@ bool KMahjonggLayout::load(const QString & file)
     // verify if it is a valid file first and if we can open it
     QFile bgfile(file);
     if (!bgfile.open(QIODevice::ReadOnly)) {
+        m_name.clear();
+        m_description.clear();
+        m_authorName.clear();
+        m_authorEmailAddress.clear();
         return false;
     }
     bgfile.close();
 
     KConfig bgconfig(file, KConfig::SimpleConfig);
-    KConfigGroup group = bgconfig.group("KMahjonggLayout");
+    KConfigGroup group = bgconfig.group(QStringLiteral("KMahjonggLayout"));
 
-    d->authorproperties.insert(QStringLiteral("Name"), group.readEntry("Name")); // Returns translated data
-    d->authorproperties.insert(QStringLiteral("Author"), group.readEntry("Author"));
-    d->authorproperties.insert(QStringLiteral("Description"), group.readEntry("Description"));
-    d->authorproperties.insert(QStringLiteral("AuthorEmail"), group.readEntry("AuthorEmail"));
+    m_name = group.readEntry("Name"); // Returns translated data
+    m_description = group.readEntry("Description");
+    m_authorName = group.readEntry("Author");
+    m_authorEmailAddress = group.readEntry("AuthorEmail");
 
     // Version control
     const int bgversion = group.readEntry("VersionFormat", 0);
@@ -100,39 +83,46 @@ bool KMahjonggLayout::load(const QString & file)
 
     const QString layoutPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, subdir + layoutFileName);
     qCDebug(KMAHJONGG_LOG) << "Using layout at" << layoutPath;
-    d->filename = layoutPath;
 
     if (layoutPath.isEmpty()) {
         return false;
     }
 
-    if (!d->board->loadBoardLayout(d->filename)) {
+    if (!m_board->loadBoardLayout(layoutPath)) {
         return false;
     }
 
-    filename = file;
-
-    m_layoutName = group.readEntry("Name");
+    m_fileName = file;
 
     return true;
 }
 
 BoardLayout * KMahjonggLayout::board() const
 {
-    return d->board;
+    return m_board.get();
 }
 
 QString KMahjonggLayout::path() const
 {
-    return filename;
+    return m_fileName;
 }
 
-QString KMahjonggLayout::authorProperty(const QString & key) const
+QString KMahjonggLayout::name() const
 {
-    return d->authorproperties[key];
+    return m_name;
 }
 
-QString KMahjonggLayout::layoutName() const
+QString KMahjonggLayout::description() const
 {
-    return m_layoutName;
+    return m_description;
+}
+
+QString KMahjonggLayout::authorName() const
+{
+    return m_authorName;
+}
+
+QString KMahjonggLayout::authorEmailAddress() const
+{
+    return m_authorEmailAddress;
 }
